AvailableNetwork class

Constructors

AvailableNetwork(String? authAlgorithm, String? bssNetworkType, bool? connectable, String? defaultCipherAlgorithm, String? flags, int? numberOfBssid, int? numberOfPhyTypesSupported, String? profileName, int? rssi, String? ssid, bool? securityEnabled, int? signalQuality)

Properties

authAlgorithm → String?
final
bssNetworkType → String?
final
connectable → bool?
final
defaultCipherAlgorithm → String?
final
flags → String?
final
hashCode → int
The hash code for this object.
no setterinherited
numberOfBssid → int?
final
numberOfPhyTypesSupported → int?
final
profileName → String?
final
rssi → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityEnabled → bool?
final
signalQuality → int?
final
ssid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited